## What's Changed

hotfix of v4.11.0

修复：

1. 修复: 部分情况下选择提供商的时候出现”暂无可用提供商的问题“，即使实际上配置了模型（提供商）。
2. 优化：提供商源 ID、提供商 ID 和模型 ID 的提示信息，帮助用户更好理解各个 ID 的含义。

### 新增

- 支持上下文自动压缩功能。入口：配置文件 -> 上下文管理策略 -> 超出模型上下文窗口时的处理方式。详情请查看： [自动上下文压缩](https://docs.astrbot.app/use/context-compress.html) ([#4322](https://github.com/AstrBotDevs/AstrBot/issues/4322))
- 新增 `on_waiting_llm_request` 事件钩子 ([#4319](https://github.com/AstrBotDevs/AstrBot/issues/4319))
- WebUI 支持强制更新插件 ([#4293](https://github.com/AstrBotDevs/AstrBot/issues/4293))
- 社区已提供适用于 [Matrix](https://github.com/stevessr/astrbot_plugin_matrix_adapter) 平台的适配器插件

### 修复

- 修复微信公众号中由于 msg.id 数据类型不匹配导致的重试失败问题 ([#4292](https://github.com/AstrBotDevs/AstrBot/issues/4292))
- 修复调用 TTS 命令时出现的数据库锁定错误 ([#4313](https://github.com/AstrBotDevs/AstrBot/issues/4313))
- 修复 Anthropic 提供商中 token 用量始终为 0 的问题 ([#4328](https://github.com/AstrBotDevs/AstrBot/issues/4328))

### 优化

- 完善共享组件的国际化支持 ([#4327](https://github.com/AstrBotDevs/AstrBot/issues/4327))
- 优化下载大型备份文件时的稳定性，减少失败情况 ([#4329](https://github.com/AstrBotDevs/AstrBot/issues/4329))
